@@ -20,6 +20,9 @@ AUTHFAILURE = 'AuthFailure'
 # Failed to add the security group information of an instance.
 FAILEDOPERATION_ADDINSTANCEINFOFAILED = 'FailedOperation.AddInstanceInfoFailed'
 
+# Failed to apply for VIP
+FAILEDOPERATION_APPLYVIPFAILED = 'FailedOperation.ApplyVipFailed'
+
 # Failed to associate the security group.
 FAILEDOPERATION_ASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.AssociateSecurityGroupsFailed'
 
@@ -56,6 +59,9 @@ FAILEDOPERATION_OSSOPERATIONFAILED = 'FailedOperation.OssOperationFailed'
 # Failed to reset the account password.
 FAILEDOPERATION_RESETPASSWORDFAILED = 'FailedOperation.ResetPasswordFailed'
 
+# Failed to update the security group
+FAILEDOPERATION_SGCHANGEVIP = 'FailedOperation.SGChangeVip'
+
 # Failed to set a rule.
 FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 
@@ -68,12 +74,24 @@ FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFa
 # Unverified user.
 FAILEDOPERATION_USERNOTAUTHED = 'FailedOperation.UserNotAuthed'
 
+# VIP can’t be the same.
+FAILEDOPERATION_VIPNOTCHANGE = 'FailedOperation.VipNotChange'
+
+# Failed to add service to VPC
+FAILEDOPERATION_VPCADDSERVICEFAILED = 'FailedOperation.VpcAddServiceFailed'
+
+# Abnormal public network status
+FAILEDOPERATION_WANSTATUSABNORMAL = 'FailedOperation.WanStatusAbnormal'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
 # CAM authentication request failed.
 INTERNALERROR_CAMAUTHFAILED = 'InternalError.CamAuthFailed'
 
+# Failed to verify the VIP status
+INTERNALERROR_CHECKVIPSTATUSFAILED = 'InternalError.CheckVipStatusFailed'
+
 # Invalid COS instance address configuration.
 INTERNALERROR_COSCONFIGURATION = 'InternalError.CosConfiguration'
 
@@ -122,6 +140,9 @@ INTERNALERROR_GETTABLEINFOFAILED = 'InternalError.GetTableInfoFailed'
 # Failed to get the list of accounts.
 INTERNALERROR_GETUSERLISTFAILED = 'InternalError.GetUserListFailed'
 
+# Failed to get the number of security groups
+INTERNALERROR_GETUSERSGCOUNTFAILED = 'InternalError.GetUserSGCountFailed'
+
 # Failed to query the security group quota of the user.
 INTERNALERROR_GETUSGQUOTAERROR = 'InternalError.GetUsgQuotaError'
 
@@ -167,6 +188,9 @@ INTERNALERROR_SETSVCLOCATIONFAILED = 'InternalError.SetSvcLocationFailed'
 # Failed to update the database.
 INTERNALERROR_UPDATEDATABASEFAILED = 'InternalError.UpdateDatabaseFailed'
 
+# VPC operation failed
+INTERNALERROR_VPCOPERATIONFAILED = 'InternalError.VpcOperationFailed'
+
 # Public network operation failed.
 INTERNALERROR_WANSERVICEFAILED = 'InternalError.WanServiceFailed'
 
@@ -206,9 +230,21 @@ INVALIDPARAMETER_SGCHECKFAIL = 'InvalidParameter.SGCheckFail'
 # The specified VPC subnet was not found.
 INVALIDPARAMETER_SUBNETNOTFOUND = 'InvalidParameter.SubnetNotFound'
 
+# The SNAT subnet doesn’t support applying for IPs.
+INVALIDPARAMETER_SUBNETUNAVAILABLE = 'InvalidParameter.SubnetUnavailable'
+
+# VIP is not in the subnet.
+INVALIDPARAMETER_VIPNOTINSUBNET = 'InvalidParameter.VipNotInSubnet'
+
+# VIP is in use.
+INVALIDPARAMETER_VIPUSED = 'InvalidParameter.VipUsed'
+
 # The specified VPC was not found.
 INVALIDPARAMETER_VPCNOTFOUND = 'InvalidParameter.VpcNotFound'
 
+# Vport is in use.
+INVALIDPARAMETER_VPORTUSED = 'InvalidParameter.VportUsed'
+
 # Incorrect AZ information.
 INVALIDPARAMETER_ZONEIDILLEGAL = 'InvalidParameter.ZoneIdIllegal'
 
