@@ -557,7 +557,7 @@ class RumClient(AbstractClient):
 
 
     def DescribeDataFetchProject(self, request):
-        """This API is used to get the DescribeDataFetchProject information.
+        """This API is used to get the `DescribeDataFetchProject` information and has been deprecated. Use `DescribeDataFetchUrl` instead.
 
         :param request: Request instance for DescribeDataFetchProject.
         :type request: :class:`tencentcloud.rum.v20210622.models.DescribeDataFetchProjectRequest`
